==> haskell-text-icu-0.7.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-text-icu/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-4f77d46bf870779140aa9a137ad33aac
key: texti_Funif0XncFe5Q3trVJQGTp
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-Funif0XncFe5Q3trVJQGTp
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-icu-0.7.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-text-icu/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-6e6eefd2e8d16edc12cf2661f6f4ef14
key: texti_BDNnVMyFWVkKtdcdAjojGW
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/text-icu-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-BDNnVMyFWVkKtdcdAjojGW
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
